ExtractArchive

Function ExtractArchive 

fn ExtractArchive(
    ArchiveType: &ArchiveType,
    ArchivePath: &Path,
    ExtractionDirectory: &Path,
) -> Result<()>
Extracts the contents of a downloaded archive to a target directory. This function now performs a full extraction to ensure a complete distribution.