fn GetPlatformMatrix() -> Vec<PlatformTarget>Expand description
Defines the matrix of platforms to target. Each entry specifies how to download and identify binaries for a specific architecture.
fn GetPlatformMatrix() -> Vec<PlatformTarget>Defines the matrix of platforms to target. Each entry specifies how to download and identify binaries for a specific architecture.